==> rad-1.0.1.tar.gz: lib/src/widgets/abstract/html_bidirectional_base.dart <==
// Copyright (c) 2022, Rad developers. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:meta/meta.dart';

import 'package:rad/src/core/common/constants.dart';
import 'package:rad/src/core/common/enums.dart';
import 'package:rad/src/core/common/objects/dom_node_patch.dart';
import 'package:rad/src/core/common/objects/key.dart';
import 'package:rad/src/core/common/types.dart';
import 'package:rad/src/widgets/abstract/html_widget_base.dart';
import 'package:rad/src/widgets/abstract/widget.dart';

/// Abstract class for Bidirectional HTML widgets.
///
@internal
abstract class HTMLBidirectionalBase extends HTMLWidgetBase {
  /// The direction in which text should be rendered.
  ///
  final DirectionType? dir;

  const HTMLBidirectionalBase({
    this.dir,
    Key? key,
    String? id,
    String? title,
    String? style,
    String? className,
    bool? hidden,
    String? innerText,
    Widget? child,
    List<Widget>? children,
    EventCallback? onClick,
    Map<String, String>? additionalAttributes,
  }) : super(
          key: key,
          id: id,
          title: title,
          style: style,
          className: className,
          hidden: hidden,
          innerText: innerText,
          child: child,
          children: children,
          onClick: onClick,
          additionalAttributes: additionalAttributes,
        );

  @override
  bool shouldUpdateWidget(
    covariant oldWidget,
  ) {
    oldWidget as HTMLBidirectionalBase;

    return dir != oldWidget.dir || super.shouldUpdateWidget(oldWidget);
  }

  @override
  createRenderElement(parent) {
    return HTMLBidirectionalBaseRenderElement(this, parent);
  }
}

/*
|--------------------------------------------------------------------------
| render element
|--------------------------------------------------------------------------
*/

/// Table's cell base render element.
///
@internal
class HTMLBidirectionalBaseRenderElement extends HTMLRenderElementBase {
  HTMLBidirectionalBaseRenderElement(super.wudget, super.parent);

  @mustCallSuper
  @override
  DomNodePatchFillable render({
    required covariant HTMLBidirectionalBase widget,
  }) {
    var domNodePatch = super.render(
      widget: widget,
    );

    _extendAttributes(
      widget: widget,
      oldWidget: null,
      attributes: domNodePatch.attributes,
    );

    return domNodePatch;
  }

  @mustCallSuper
  @override
  DomNodePatchFillable update({
    required updateType,
    required covariant HTMLBidirectionalBase oldWidget,
    required covariant HTMLBidirectionalBase newWidget,
  }) {
    var domNodePatch = super.update(
      updateType: updateType,
      oldWidget: oldWidget,
      newWidget: newWidget,
    );

    _extendAttributes(
      widget: newWidget,
      oldWidget: oldWidget,
      attributes: domNodePatch.attributes,
    );

    return domNodePatch;
  }
}

/*
|--------------------------------------------------------------------------
| patch
|--------------------------------------------------------------------------
*/

void _extendAttributes({
  required HTMLBidirectionalBase widget,
  required HTMLBidirectionalBase? oldWidget,
  required Map<String, String?> attributes,
}) {
  if (widget.dir != oldWidget?.dir) {
    attributes[Attributes.dir] = widget.dir?.nativeValue;
  }
}

==> rad-1.3.0.tar.gz: lib/src/widgets/abstract/html_bidirectional_base.dart <==
// Copyright (c) 2022, Rad developers. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import 'package:meta/meta.dart';

import 'package:rad/src/core/common/constants.dart';
import 'package:rad/src/core/common/enums.dart';
import 'package:rad/src/core/common/objects/dom_node_patch.dart';
import 'package:rad/src/core/common/objects/key.dart';
import 'package:rad/src/core/common/types.dart';
import 'package:rad/src/widgets/abstract/html_widget_base.dart';
import 'package:rad/src/widgets/abstract/widget.dart';

/// Abstract class for Bidirectional HTML widgets.
///
@internal
abstract class HTMLBidirectionalBase extends HTMLWidgetBase {
  /// The direction in which text should be rendered.
  ///
  final DirectionType? dir;

  const HTMLBidirectionalBase({
    this.dir,
    Key? key,
    String? id,
    String? title,
    String? style,
    String? className,
    bool? hidden,
    String? innerText,
    Widget? child,
    List<Widget>? children,
    EventCallback? onClick,
    Map<String, String>? additionalAttributes,
  }) : super(
          key: key,
          id: id,
          title: title,
          style: style,
          className: className,
          hidden: hidden,
          innerText: innerText,
          child: child,
          children: children,
          onClick: onClick,
          additionalAttributes: additionalAttributes,
        );

  @override
  bool shouldUpdateWidget(
    covariant oldWidget,
  ) {
    oldWidget as HTMLBidirectionalBase;

    return dir != oldWidget.dir || super.shouldUpdateWidget(oldWidget);
  }

  @override
  createRenderElement(parent) {
    return HTMLBidirectionalBaseRenderElement(this, parent);
  }
}

/*
|--------------------------------------------------------------------------
| render element
|--------------------------------------------------------------------------
*/

/// Table's cell base render element.
///
@internal
class HTMLBidirectionalBaseRenderElement extends HTMLRenderElementBase {
  HTMLBidirectionalBaseRenderElement(super.widget, super.parent);

  @mustCallSuper
  @override
  DomNodePatchFillable render({
    required covariant HTMLBidirectionalBase widget,
  }) {
    var domNodePatch = super.render(
      widget: widget,
    );

    _extendAttributes(
      widget: widget,
      oldWidget: null,
      attributes: domNodePatch.attributes,
    );

    return domNodePatch;
  }

  @mustCallSuper
  @override
  DomNodePatchFillable update({
    required updateType,
    required covariant HTMLBidirectionalBase oldWidget,
    required covariant HTMLBidirectionalBase newWidget,
  }) {
    var domNodePatch = super.update(
      updateType: updateType,
      oldWidget: oldWidget,
      newWidget: newWidget,
    );

    _extendAttributes(
      widget: newWidget,
      oldWidget: oldWidget,
      attributes: domNodePatch.attributes,
    );

    return domNodePatch;
  }
}

/*
|--------------------------------------------------------------------------
| patch
|--------------------------------------------------------------------------
*/

void _extendAttributes({
  required HTMLBidirectionalBase widget,
  required HTMLBidirectionalBase? oldWidget,
  required Map<String, String?> attributes,
}) {
  if (widget.dir != oldWidget?.dir) {
    attributes[Attributes.dir] = widget.dir?.nativeValue;
  }
}
